==> payroll_ver_3.2.0.zip: payroll3/src/jp/mosp/common/MosPMenuConst.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.common;

public class MosPMenuConst {

	protected static final String NAM_ATTENDANCE_CALCULATE	= "<ΑӌvZ>"; 	

	/*l֘A*/
	private static final String[] MENU_HUMAN 				= { "H1010", "Јꗗ"		};
	private static final String[] MENU_HUMAN_INSERT 		= { "H1020", "ЈVKo^"	};

	/*ΑӏWv֘A*/
	private static final String[] MENU_ATTENDANCE_CALCULATE 		= { "P1010", "ΑӌvZ"		};
	private static final String[] MENU_ATTENDANCE_CALCULATE_START = { "P1020", "vZJn"		};
	private static final String[] MENU_ATTENDANCE_COMPILE 		= { "P1030", "ΑӏWv"		};
	private static final String[] MENU_COMPILE_AMENDMENT 			= { "P1040", "ΑӏC"		};
	private static final String[] MENU_ATTENDANCE_EXPORT 			= { "P1050", "[o"		};
	private static final String[] MENU_ATTENDANCE_CALCULATE_END 	= { "P1060", "vZI"		};
	private static final String[] MENU_KEISAN_INFORMATION 		= { "S1100", "ΑӌvZ"	};
	private static final String[] MENU_EXPORT 					= { "S1200", "GNX|[g"	};

	/*L֘A*/
	private static final String[] MENU_YUKYU_MANAGEMENT = { "P1110", "LxǗ"	};

	/*Αӊ֘A*/
	private static final String[] MENU_ATTENDANCE 			= { "K1010", "Α"			};
	private static final String[] MENU_SCHEDULE 				= { "K1200", "XPW["	};
	private static final String[] MENU_PAID_HOLIDAY 			= { "K1300", "LxmF"		};
	private static final String[] MENU_MOSP_PASSWORD 			= { "C1050", "pX[hύX"	};
	private static final String[] MENU_EMPLOYEE_ATTENDANCE 	= { "K2010", "Јꗗ"		};

	/*VXe֘A*/
	private static final String[] MENU_KAISYA_MASTER 				= { "S2010", "Ə}X^ێ"	};
	private static final String[] MENU_SYOZOKU_MASTER 			= { "S2100", "}X^ێ"		};
	private static final String[] MENU_YAKUSYOKU_MASTER 			= { "S2200", "E}X^ێ"		};
	private static final String[] MENU_KINTAI_SYSTEM_DEFINITION 	= { "S2500", "Αӏݒ"		};
	private static final String[] MENU_REASON_MENU 				= { "S2590", "e헝Rݒ"		};
	private static final String[] MENU_YUKYU_INFORMATION 			= { "S2700", "Lxݒ"		};
	private static final String[] MENU_WORK_TYPE_MASTER 			= { "S2600", "Ζ`ԃ}X^ێ"	};
	private static final String[] MENU_HOLIDAY_MASTER 			= { "S2710", "jՓ}X^ێ"	};
	private static final String[] MENU_ACCOUNT_MASTER 			= { "S2400", "AJEgǗ"		};
	private static final String[] MENU_CODE_MASTER 				= { "S2300", "R[h}X^ێ"	};
	private static final String[] MENU_CM_CODE 					= { "S2000", "ʃR[hێ"		};
	private static final String[] MENU_APPROVAL 					= { "S2800", "Fݒ"		};

	private static final String[] MENU_OPTION_FUNCTION = { "O9910", "IvVێ"	};

	/*\֘A*/
	private static final String[] MENU_APPLICATION 			= { "K1400", "e\"		};
	private static final String[] MENU_OVER_TIME_REQUEST 		= { "K1410", "cƐ\"		};

	/*F֘A*/
	private static final String[] MENU_MANAGER_APPROVAL 		= { "K2100", "e폳F"		};
	private static final String[] MENU_EMPLOYEE_APPROVAL 		= { "K2110", "ΑӏF"		};
	private static final String[] MENU_RELEVANT_KINTAI 		= { "K2130", "Αӊ֘AF"	};


	/*]ƈpR}h̔z*/
	private static final String[][] CMD_EMPLOYEE_ARRAY = {
		MENU_ATTENDANCE,
		MENU_SCHEDULE,
		MENU_PAID_HOLIDAY,
		MENU_APPLICATION,
		MENU_MOSP_PASSWORD
	};

	/*}l[W[pR}h̔z*/
	private static final String[][] CMD_MANAGER_ARRAY = {
		MENU_EMPLOYEE_ATTENDANCE,
		MENU_MANAGER_APPROVAL
	};

	/*^pR}h̔z*/
	private static final String[][] CMD_PAYROLL_ARRAY = {
		MENU_ATTENDANCE_CALCULATE,
		MENU_ATTENDANCE_CALCULATE_START,
		MENU_ATTENDANCE_COMPILE,
		MENU_COMPILE_AMENDMENT,
		MENU_ATTENDANCE_EXPORT,
		MENU_ATTENDANCE_CALCULATE_END,
		MENU_YUKYU_MANAGEMENT,
		MENU_KEISAN_INFORMATION,		
		MENU_EXPORT
	};

	/*lpR}h̔z*/
	private static final String[][] CMD_HUMAN_ARRAY = {
		MENU_HUMAN,
		MENU_HUMAN_INSERT
	};

	/*ΑӌvZpR}h̔z*/
	private static final String[] CMD_CALC_ARRAY = {
		MENU_ATTENDANCE_CALCULATE[0],
		MENU_ATTENDANCE_CALCULATE_START[0],
		MENU_ATTENDANCE_COMPILE[0],
		MENU_COMPILE_AMENDMENT[0],
		MENU_ATTENDANCE_EXPORT[0],
		MENU_ATTENDANCE_CALCULATE_END[0]
	};

	/*VXepR}h̔z*/
	private static final String[][] CMD_SYSTEM_ARRAY = {
		MENU_KAISYA_MASTER,
		MENU_SYOZOKU_MASTER,
		MENU_YAKUSYOKU_MASTER,
		MENU_KINTAI_SYSTEM_DEFINITION,
		MENU_REASON_MENU,
		MENU_YUKYU_INFORMATION,
		MENU_WORK_TYPE_MASTER,
		MENU_HOLIDAY_MASTER,
//		MENU_ACCOUNT_MASTER,
//		MENU_MOSP_PASSWORD,
//		MENU_CODE_MASTER,
//		MENU_CM_CODE,
		MENU_APPROVAL,
		MENU_OPTION_FUNCTION
	};

	/**
	 * ^(vZ@\)pR}h̔z쐬 cmd,name
	 * @return array
	 */
	public static String[][] getPayrollRestrictCalcArray() {
		String[][] array = {								
				MENU_ATTENDANCE_COMPILE,
				MENU_COMPILE_AMENDMENT,
				MENU_ATTENDANCE_EXPORT,				
				MENU_YUKYU_MANAGEMENT
		};
		return array.clone();
	}

	/**
	 * ^o^ʕ\pR}h̔z쐬 cmd,name
	 * @return array
	 */
	public static String[][] getViewPayrollCmdArray() {
		String[][] array = {
				{ MENU_ATTENDANCE_CALCULATE_START[0],	NAM_ATTENDANCE_CALCULATE + MENU_ATTENDANCE_CALCULATE_START[1]	},
				{ MENU_ATTENDANCE_COMPILE[0]		,	NAM_ATTENDANCE_CALCULATE + MENU_ATTENDANCE_COMPILE[1]			},
				{ MENU_COMPILE_AMENDMENT[0]			,	NAM_ATTENDANCE_CALCULATE + MENU_COMPILE_AMENDMENT[1]			},
				{ MENU_ATTENDANCE_EXPORT[0]			,	NAM_ATTENDANCE_CALCULATE + MENU_ATTENDANCE_EXPORT[1]			},
				{ MENU_ATTENDANCE_CALCULATE_END[0]	,	NAM_ATTENDANCE_CALCULATE + MENU_ATTENDANCE_CALCULATE_END[1]		},
				MENU_YUKYU_MANAGEMENT,
				MENU_KEISAN_INFORMATION,		
				MENU_EXPORT
		};
		return array.clone();
	}

	// ANZT\bh
	/**
	 * ]ƈpR}h̔z
	 * @return array
	 */
	public static String[][] getEmployeeCmdArray() {
		return CMD_EMPLOYEE_ARRAY.clone();
	}

	/**
	 * }l[W[pR}h̔z
	 * @return array
	 */
	public static String[][] getManagerCmdArray() {
		return CMD_MANAGER_ARRAY.clone();
	}

	/**
	 * ^pR}h̔z
	 * @return array
	 */
	public static String[][] getPayrollCmdArray() {
		return CMD_PAYROLL_ARRAY.clone();
	}

	/**
	 * lpR}h̔z
	 * @return array
	 */
	public static  String[][] getHumanCmdArray() {
		return CMD_HUMAN_ARRAY.clone();
	}

	/**
	 * ΑӌvZpR}h̔z
	 * @return array
	 */
	public static String[] getCalcCmdArray() {
		return CMD_CALC_ARRAY.clone();
	}

	/**
	 * VXepR}h̔z
	 * @return array
	 */
	public static String[][] getSystemCmdArray() {
		return CMD_SYSTEM_ARRAY.clone();
	}

	/**
	 * e\j[R}hz擾
	 * @return	e\j[R}hz
	 */
	public static String[][] getApplicationCmdArray() {
		return new String[][] {
				MENU_OVER_TIME_REQUEST
		};
	}

	/**
	 * e폳Fj[R}hz擾
	 * @return	e폳Fj[R}hz
	 */
	public static String[][] getApprovalCmdArray() {
		return new String[][] {
				MENU_EMPLOYEE_APPROVAL,
				MENU_RELEVANT_KINTAI
		};
	}


	protected static String[] MENU_HUMAN() {
		return MENU_HUMAN.clone();
	}

	protected static String[] MENU_ACCOUNT_MASTER() {
		return MENU_ACCOUNT_MASTER.clone();
	}

	protected static String[] MENU_APPROVAL() {
		return MENU_APPROVAL.clone();
	}

	protected static String[] MENU_ATTENDANCE() {
		return MENU_ATTENDANCE.clone();
	}

	protected static String[] MENU_ATTENDANCE_CALCULATE() {
		return MENU_ATTENDANCE_CALCULATE.clone();
	}

	protected static String[] MENU_ATTENDANCE_CALCULATE_END() {
		return MENU_ATTENDANCE_CALCULATE_END.clone();
	}

	protected static String[] MENU_ATTENDANCE_CALCULATE_START() {
		return MENU_ATTENDANCE_CALCULATE_START.clone();
	}

	protected static String[] MENU_ATTENDANCE_COMPILE() {
		return MENU_ATTENDANCE_COMPILE.clone();
	}

	protected static String[] MENU_ATTENDANCE_EXPORT() {
		return MENU_ATTENDANCE_EXPORT.clone();
	}

	protected static String[] MENU_CM_CODE() {
		return MENU_CM_CODE.clone();
	}

	protected static String[] MENU_CODE_MASTER() {
		return MENU_CODE_MASTER.clone();
	}

	protected static String[] MENU_COMPILE_AMENDMENT() {
		return MENU_COMPILE_AMENDMENT.clone();
	}

	protected static String[] MENU_EMPLOYEE_APPROVAL() {
		return MENU_EMPLOYEE_APPROVAL.clone();
	}

	protected static String[] MENU_EMPLOYEE_ATTENDANCE() {
		return MENU_EMPLOYEE_ATTENDANCE.clone();
	}

	protected static String[] MENU_EXPORT() {
		return MENU_EXPORT.clone();
	}

	protected static String[] MENU_HOLIDAY_MASTER() {
		return MENU_HOLIDAY_MASTER.clone();
	}

	protected static String[] MENU_HUMAN_INSERT() {
		return MENU_HUMAN_INSERT.clone();
	}

	protected static String[] MENU_KAISYA_MASTER() {
		return MENU_KAISYA_MASTER.clone();
	}

	protected static String[] MENU_KEISAN_INFORMATION() {
		return MENU_KEISAN_INFORMATION.clone();
	}

	protected static String[] MENU_KINTAI_SYSTEM_DEFINITION() {
		return MENU_KINTAI_SYSTEM_DEFINITION.clone();
	}

	protected static String[] MENU_MOSP_PASSWORD() {
		return MENU_MOSP_PASSWORD.clone();
	}

	protected static String[] MENU_OPTION_FUNCTION() {
		return MENU_OPTION_FUNCTION.clone();
	}

	protected static String[] MENU_PAID_HOLIDAY() {
		return MENU_PAID_HOLIDAY.clone();
	}

	protected static String[] MENU_REASON_MENU() {
		return MENU_REASON_MENU.clone();
	}

	protected static String[] MENU_SCHEDULE() {
		return MENU_SCHEDULE.clone();
	}

	protected static String[] MENU_SYOZOKU_MASTER() {
		return MENU_SYOZOKU_MASTER.clone();
	}

	protected static String[] MENU_WORK_TYPE_MASTER() {
		return MENU_WORK_TYPE_MASTER.clone();
	}

	protected static String[] MENU_YAKUSYOKU_MASTER() {
		return MENU_YAKUSYOKU_MASTER.clone();
	}

	protected static String[] MENU_YUKYU_INFORMATION() {
		return MENU_YUKYU_INFORMATION.clone();
	}

	protected static String[] MENU_YUKYU_MANAGEMENT() {
		return MENU_YUKYU_MANAGEMENT.clone();
	}

	/**
	 * e\
	 * @return	e\
	 */
	protected String[] MENU_APPLICATION() {
		return MENU_APPLICATION.clone();
	}

}

==> payroll_ver_3.2.1.zip: payroll3/src/jp/mosp/common/MosPMenuConst.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.common;

public class MosPMenuConst {

	protected static final String NAM_ATTENDANCE_CALCULATE	= "<ΑӌvZ>"; 	

	/*l֘A*/
	private static final String[] MENU_HUMAN 				= { "H1010", "Јꗗ"		};
	private static final String[] MENU_HUMAN_INSERT 		= { "H1020", "ЈVKo^"	};

	/*ΑӏWv֘A*/
	private static final String[] MENU_ATTENDANCE_CALCULATE 		= { "P1010", "ΑӌvZ"		};
	private static final String[] MENU_ATTENDANCE_CALCULATE_START = { "P1020", "vZJn"		};
	private static final String[] MENU_ATTENDANCE_COMPILE 		= { "P1030", "ΑӏWv"		};
	private static final String[] MENU_COMPILE_AMENDMENT 			= { "P1040", "ΑӏC"		};
	private static final String[] MENU_ATTENDANCE_EXPORT 			= { "P1050", "[o"		};
	private static final String[] MENU_ATTENDANCE_CALCULATE_END 	= { "P1060", "vZI"		};
	private static final String[] MENU_KEISAN_INFORMATION 		= { "S1100", "ΑӌvZ"	};
	private static final String[] MENU_EXPORT 					= { "S1200", "GNX|[g"	};

	/*L֘A*/
	private static final String[] MENU_YUKYU_MANAGEMENT = { "P1110", "LxǗ"	};

	/*Αӊ֘A*/
	private static final String[] MENU_ATTENDANCE 			= { "K1010", "Α"			};
	private static final String[] MENU_SCHEDULE 				= { "K1200", "XPW["	};
	private static final String[] MENU_PAID_HOLIDAY 			= { "K1300", "LxmF"		};
	private static final String[] MENU_MOSP_PASSWORD 			= { "C1050", "pX[hύX"	};
	private static final String[] MENU_EMPLOYEE_ATTENDANCE 	= { "K2010", "Јꗗ"		};

	/*VXe֘A*/
	private static final String[] MENU_KAISYA_MASTER 				= { "S2010", "Ə}X^ێ"	};
	private static final String[] MENU_SYOZOKU_MASTER 			= { "S2100", "}X^ێ"		};
	private static final String[] MENU_YAKUSYOKU_MASTER 			= { "S2200", "E}X^ێ"		};
	private static final String[] MENU_KINTAI_SYSTEM_DEFINITION 	= { "S2500", "Αӏݒ"		};
	private static final String[] MENU_REASON_MENU 				= { "S2590", "e헝Rݒ"		};
	private static final String[] MENU_YUKYU_INFORMATION 			= { "S2700", "Lxݒ"		};
	private static final String[] MENU_WORK_TYPE_MASTER 			= { "S2600", "Ζ`ԃ}X^ێ"	};
	private static final String[] MENU_HOLIDAY_MASTER 			= { "S2710", "jՓ}X^ێ"	};
	private static final String[] MENU_ACCOUNT_MASTER 			= { "S2400", "AJEgǗ"		};
	private static final String[] MENU_CODE_MASTER 				= { "S2300", "R[h}X^ێ"	};
	private static final String[] MENU_CM_CODE 					= { "S2000", "ʃR[hێ"		};
	private static final String[] MENU_APPROVAL 					= { "S2800", "Fݒ"		};

	private static final String[] MENU_OPTION_FUNCTION = { "O9910", "IvVێ"	};

	/*\֘A*/
	private static final String[] MENU_APPLICATION 			= { "K1400", "e\"		};
	private static final String[] MENU_OVER_TIME_REQUEST 		= { "K1410", "cƐ\"		};

	/*F֘A*/
	private static final String[] MENU_MANAGER_APPROVAL 		= { "K2100", "e폳F"		};
	private static final String[] MENU_EMPLOYEE_APPROVAL 		= { "K2110", "ΑӏF"		};
	private static final String[] MENU_RELEVANT_KINTAI 		= { "K2130", "Αӊ֘AF"	};


	/*]ƈpR}h̔z*/
	private static final String[][] CMD_EMPLOYEE_ARRAY = {
		MENU_ATTENDANCE,
		MENU_SCHEDULE,
		MENU_PAID_HOLIDAY,
		MENU_APPLICATION,
		MENU_MOSP_PASSWORD
	};

	/*}l[W[pR}h̔z*/
	private static final String[][] CMD_MANAGER_ARRAY = {
		MENU_EMPLOYEE_ATTENDANCE,
		MENU_MANAGER_APPROVAL
	};

	/*^pR}h̔z*/
	private static final String[][] CMD_PAYROLL_ARRAY = {
		MENU_ATTENDANCE_CALCULATE,
		MENU_ATTENDANCE_CALCULATE_START,
		MENU_ATTENDANCE_COMPILE,
		MENU_COMPILE_AMENDMENT,
		MENU_ATTENDANCE_EXPORT,
		MENU_ATTENDANCE_CALCULATE_END,
		MENU_YUKYU_MANAGEMENT,
		MENU_KEISAN_INFORMATION,		
		MENU_EXPORT
	};

	/*lpR}h̔z*/
	private static final String[][] CMD_HUMAN_ARRAY = {
		MENU_HUMAN,
		MENU_HUMAN_INSERT
	};

	/*ΑӌvZpR}h̔z*/
	private static final String[] CMD_CALC_ARRAY = {
		MENU_ATTENDANCE_CALCULATE[0],
		MENU_ATTENDANCE_CALCULATE_START[0],
		MENU_ATTENDANCE_COMPILE[0],
		MENU_COMPILE_AMENDMENT[0],
		MENU_ATTENDANCE_EXPORT[0],
		MENU_ATTENDANCE_CALCULATE_END[0]
	};

	/*VXepR}h̔z*/
	private static final String[][] CMD_SYSTEM_ARRAY = {
		MENU_KAISYA_MASTER,
		MENU_SYOZOKU_MASTER,
		MENU_YAKUSYOKU_MASTER,
		MENU_KINTAI_SYSTEM_DEFINITION,
		MENU_REASON_MENU,
		MENU_YUKYU_INFORMATION,
		MENU_WORK_TYPE_MASTER,
		MENU_HOLIDAY_MASTER,
		MENU_ACCOUNT_MASTER,
		MENU_MOSP_PASSWORD,
		MENU_CODE_MASTER,
		MENU_CM_CODE,
		MENU_APPROVAL,
		MENU_OPTION_FUNCTION
	};

	/**
	 * ^(vZ@\)pR}h̔z쐬 cmd,name
	 * @return array
	 */
	public static String[][] getPayrollRestrictCalcArray() {
		String[][] array = {								
				MENU_ATTENDANCE_COMPILE,
				MENU_COMPILE_AMENDMENT,
				MENU_ATTENDANCE_EXPORT,				
				MENU_YUKYU_MANAGEMENT
		};
		return array.clone();
	}

	/**
	 * ^o^ʕ\pR}h̔z쐬 cmd,name
	 * @return array
	 */
	public static String[][] getViewPayrollCmdArray() {
		String[][] array = {
				{ MENU_ATTENDANCE_CALCULATE_START[0],	NAM_ATTENDANCE_CALCULATE + MENU_ATTENDANCE_CALCULATE_START[1]	},
				{ MENU_ATTENDANCE_COMPILE[0]		,	NAM_ATTENDANCE_CALCULATE + MENU_ATTENDANCE_COMPILE[1]			},
				{ MENU_COMPILE_AMENDMENT[0]			,	NAM_ATTENDANCE_CALCULATE + MENU_COMPILE_AMENDMENT[1]			},
				{ MENU_ATTENDANCE_EXPORT[0]			,	NAM_ATTENDANCE_CALCULATE + MENU_ATTENDANCE_EXPORT[1]			},
				{ MENU_ATTENDANCE_CALCULATE_END[0]	,	NAM_ATTENDANCE_CALCULATE + MENU_ATTENDANCE_CALCULATE_END[1]		},
				MENU_YUKYU_MANAGEMENT,
				MENU_KEISAN_INFORMATION,		
				MENU_EXPORT
		};
		return array.clone();
	}

	// ANZT\bh
	/**
	 * ]ƈpR}h̔z
	 * @return array
	 */
	public static String[][] getEmployeeCmdArray() {
		return CMD_EMPLOYEE_ARRAY.clone();
	}

	/**
	 * }l[W[pR}h̔z
	 * @return array
	 */
	public static String[][] getManagerCmdArray() {
		return CMD_MANAGER_ARRAY.clone();
	}

	/**
	 * ^pR}h̔z
	 * @return array
	 */
	public static String[][] getPayrollCmdArray() {
		return CMD_PAYROLL_ARRAY.clone();
	}

	/**
	 * lpR}h̔z
	 * @return array
	 */
	public static  String[][] getHumanCmdArray() {
		return CMD_HUMAN_ARRAY.clone();
	}

	/**
	 * ΑӌvZpR}h̔z
	 * @return array
	 */
	public static String[] getCalcCmdArray() {
		return CMD_CALC_ARRAY.clone();
	}

	/**
	 * VXepR}h̔z
	 * @return array
	 */
	public static String[][] getSystemCmdArray() {
		return CMD_SYSTEM_ARRAY.clone();
	}

	/**
	 * e\j[R}hz擾
	 * @return	e\j[R}hz
	 */
	public static String[][] getApplicationCmdArray() {
		return new String[][] {
				MENU_OVER_TIME_REQUEST
		};
	}

	/**
	 * e폳Fj[R}hz擾
	 * @return	e폳Fj[R}hz
	 */
	public static String[][] getApprovalCmdArray() {
		return new String[][] {
				MENU_EMPLOYEE_APPROVAL,
				MENU_RELEVANT_KINTAI
		};
	}


	protected static String[] MENU_HUMAN() {
		return MENU_HUMAN.clone();
	}

	protected static String[] MENU_ACCOUNT_MASTER() {
		return MENU_ACCOUNT_MASTER.clone();
	}

	protected static String[] MENU_APPROVAL() {
		return MENU_APPROVAL.clone();
	}

	protected static String[] MENU_ATTENDANCE() {
		return MENU_ATTENDANCE.clone();
	}

	protected static String[] MENU_ATTENDANCE_CALCULATE() {
		return MENU_ATTENDANCE_CALCULATE.clone();
	}

	protected static String[] MENU_ATTENDANCE_CALCULATE_END() {
		return MENU_ATTENDANCE_CALCULATE_END.clone();
	}

	protected static String[] MENU_ATTENDANCE_CALCULATE_START() {
		return MENU_ATTENDANCE_CALCULATE_START.clone();
	}

	protected static String[] MENU_ATTENDANCE_COMPILE() {
		return MENU_ATTENDANCE_COMPILE.clone();
	}

	protected static String[] MENU_ATTENDANCE_EXPORT() {
		return MENU_ATTENDANCE_EXPORT.clone();
	}

	protected static String[] MENU_CM_CODE() {
		return MENU_CM_CODE.clone();
	}

	protected static String[] MENU_CODE_MASTER() {
		return MENU_CODE_MASTER.clone();
	}

	protected static String[] MENU_COMPILE_AMENDMENT() {
		return MENU_COMPILE_AMENDMENT.clone();
	}

	protected static String[] MENU_EMPLOYEE_APPROVAL() {
		return MENU_EMPLOYEE_APPROVAL.clone();
	}

	protected static String[] MENU_EMPLOYEE_ATTENDANCE() {
		return MENU_EMPLOYEE_ATTENDANCE.clone();
	}

	protected static String[] MENU_EXPORT() {
		return MENU_EXPORT.clone();
	}

	protected static String[] MENU_HOLIDAY_MASTER() {
		return MENU_HOLIDAY_MASTER.clone();
	}

	protected static String[] MENU_HUMAN_INSERT() {
		return MENU_HUMAN_INSERT.clone();
	}

	protected static String[] MENU_KAISYA_MASTER() {
		return MENU_KAISYA_MASTER.clone();
	}

	protected static String[] MENU_KEISAN_INFORMATION() {
		return MENU_KEISAN_INFORMATION.clone();
	}

	protected static String[] MENU_KINTAI_SYSTEM_DEFINITION() {
		return MENU_KINTAI_SYSTEM_DEFINITION.clone();
	}

	protected static String[] MENU_MOSP_PASSWORD() {
		return MENU_MOSP_PASSWORD.clone();
	}

	protected static String[] MENU_OPTION_FUNCTION() {
		return MENU_OPTION_FUNCTION.clone();
	}

	protected static String[] MENU_PAID_HOLIDAY() {
		return MENU_PAID_HOLIDAY.clone();
	}

	protected static String[] MENU_REASON_MENU() {
		return MENU_REASON_MENU.clone();
	}

	protected static String[] MENU_SCHEDULE() {
		return MENU_SCHEDULE.clone();
	}

	protected static String[] MENU_SYOZOKU_MASTER() {
		return MENU_SYOZOKU_MASTER.clone();
	}

	protected static String[] MENU_WORK_TYPE_MASTER() {
		return MENU_WORK_TYPE_MASTER.clone();
	}

	protected static String[] MENU_YAKUSYOKU_MASTER() {
		return MENU_YAKUSYOKU_MASTER.clone();
	}

	protected static String[] MENU_YUKYU_INFORMATION() {
		return MENU_YUKYU_INFORMATION.clone();
	}

	protected static String[] MENU_YUKYU_MANAGEMENT() {
		return MENU_YUKYU_MANAGEMENT.clone();
	}

	/**
	 * e\
	 * @return	e\
	 */
	protected String[] MENU_APPLICATION() {
		return MENU_APPLICATION.clone();
	}

}
